==> edge-login-ui-rn-2.20.0.tgz: package/lib/components/scenes/LandingScene.js <==
import * as React from 'react';
import { Text, View } from 'react-native';
import { lstrings } from '../../common/locales/strings';
import * as Constants from '../../constants/index';
import { useHandler } from '../../hooks/useHandler';
import { useImports } from '../../hooks/useImports';
import { useDispatch } from '../../types/ReduxTypes';
import { scale } from '../../util/scaling';
import { LogoImageHeader } from '../abSpecific/LogoImageHeader';
import { MainButton } from '../themed/MainButton';
import { ThemedScene } from '../themed/ThemedScene';
export const LandingScene = (props) => {
    const dispatch = useDispatch();
    const { initialUserInfo, onLogEvent = (event, values) => { } } = useImports();
    const handleCreate = useHandler(() => {
        onLogEvent('Signup_Create_Account');
        dispatch({
            type: 'NAVIGATE',
            data: { name: 'newAccountWelcome', params: {} }
        });
    });
    const handlePassword = useHandler(() => {
        var _a;
        onLogEvent('Signup_Signin');
        dispatch({
            type: 'NAVIGATE',
            data: {
                name: 'passwordLogin',
                params: { username: (_a = initialUserInfo === null || initialUserInfo === void 0 ? void 0 : initialUserInfo.username) !== null && _a !== void 0 ? _a : '' }
            }
        });
    });
    return (React.createElement(ThemedScene, { branding: props.branding, noUnderline: true },
        React.createElement(View, { style: styles.container },
            React.createElement(View, { style: styles.inner },
                React.createElement(View, { style: styles.featureBox },
                    React.createElement(LogoImageHeader, { branding: props.branding }),
                    React.createElement(View, { style: styles.featureBoxContent },
                        React.createElement(View, { style: styles.featureBoxDescription },
                            React.createElement(Text, { style: styles.tagText }, props.landingSceneText || lstrings.landing_tagline))),
                    React.createElement(View, { style: styles.createButtonBox },
                        React.createElement(MainButton, { testID: "createAccountButton", label: lstrings.get_started, type: "secondary", onPress: handleCreate })),
                    React.createElement(View, { style: styles.loginButtonBox },
                        React.createElement(MainButton, { testID: "alreadyHaveAccountButton", onPress: handlePassword, label: lstrings.landing_already_have_account, type: "textOnly" })))))));
};
const styles = {
    container: {
        flex: 1,
        width: '100%',
        height: '100%'
    },
    inner: {
        position: 'relative',
        flex: 1,
        width: '100%',
        height: '100%'
    },
    featureBox: {
        position: 'relative',
        top: scale(71),
        width: '100%',
        height: scale(286)
    },
    featureBoxContent: {
        // height: scale(186), 306- 125 - remaining space.
        width: '100%',
        flexDirection: 'column',
        height: scale(166),
        alignItems: 'center',
        justifyContent: 'flex-start'
    },
    featureBoxDescription: {
        // height: scale(186), 306- 125 - remaining space.
        width: '100%',
        justifyContent: 'flex-end'
    },
    createButtonBox: {
        alignSelf: 'center',
        width: '70%'
    },
    loginButtonBox: {
        alignItems: 'center',
        justifyContent: 'flex-end',
        marginTop: scale(28)
    },
    tagText: {
        width: '80%',
        marginLeft: '10%',
        marginRight: '10%',
        color: Constants.WHITE,
        fontFamily: Constants.FONTS.fontFamilyRegular,
        textAlign: 'center',
        fontSize: scale(14),
        lineHeight: scale(18)
    }
};

==> edge-login-ui-rn-3.1.2.tgz: package/lib/components/scenes/LandingScene.js <==
import * as React from 'react';
import { Text, View } from 'react-native';
import { lstrings } from '../../common/locales/strings';
import * as Constants from '../../constants/index';
import { useHandler } from '../../hooks/useHandler';
import { useImports } from '../../hooks/useImports';
import { useDispatch } from '../../types/ReduxTypes';
import { scale } from '../../util/scaling';
import { LogoImageHeader } from '../abSpecific/LogoImageHeader';
import { MainButton } from '../themed/MainButton';
import { ThemedScene } from '../themed/ThemedScene';
export const LandingScene = (props) => {
    const dispatch = useDispatch();
    const { initialUserInfo, onLogEvent = () => { } } = useImports();
    const handleCreate = useHandler(() => {
        onLogEvent('Signup_Create_Account');
        dispatch({
            type: 'NAVIGATE',
            data: { name: 'newAccountWelcome', params: {} }
        });
    });
    const handlePassword = useHandler(() => {
        var _a;
        onLogEvent('Signup_Signin');
        dispatch({
            type: 'NAVIGATE',
            data: {
                name: 'passwordLogin',
                params: { username: (_a = initialUserInfo === null || initialUserInfo === void 0 ? void 0 : initialUserInfo.username) !== null && _a !== void 0 ? _a : '' }
            }
        });
    });
    return (React.createElement(ThemedScene, { branding: props.branding, noUnderline: true },
        React.createElement(View, { style: styles.container },
            React.createElement(View, { style: styles.inner },
                React.createElement(View, { style: styles.featureBox },
                    React.createElement(LogoImageHeader, { branding: props.branding }),
                    React.createElement(View, { style: styles.featureBoxContent },
                        React.createElement(View, { style: styles.featureBoxDescription },
                            React.createElement(Text, { style: styles.tagText }, props.landingSceneText || lstrings.landing_tagline))),
                    React.createElement(View, { style: styles.createButtonBox },
                        React.createElement(MainButton, { testID: "createAccountButton", label: lstrings.get_started, type: "secondary", onPress: handleCreate })),
                    React.createElement(View, { style: styles.loginButtonBox },
                        React.createElement(MainButton, { testID: "alreadyHaveAccountButton", onPress: handlePassword, label: lstrings.landing_already_have_account, type: "textOnly" })))))));
};
const styles = {
    container: {
        flex: 1,
        width: '100%',
        height: '100%'
    },
    inner: {
        position: 'relative',
        flex: 1,
        width: '100%',
        height: '100%'
    },
    featureBox: {
        position: 'relative',
        top: scale(71),
        width: '100%',
        height: scale(286)
    },
    featureBoxContent: {
        // height: scale(186), 306- 125 - remaining space.
        width: '100%',
        flexDirection: 'column',
        height: scale(166),
        alignItems: 'center',
        justifyContent: 'flex-start'
    },
    featureBoxDescription: {
        // height: scale(186), 306- 125 - remaining space.
        width: '100%',
        justifyContent: 'flex-end'
    },
    createButtonBox: {
        alignSelf: 'center',
        width: '70%'
    },
    loginButtonBox: {
        alignItems: 'center',
        justifyContent: 'flex-end',
        marginTop: scale(28)
    },
    tagText: {
        width: '80%',
        marginLeft: '10%',
        marginRight: '10%',
        color: Constants.WHITE,
        fontFamily: Constants.FONTS.fontFamilyRegular,
        textAlign: 'center',
        fontSize: scale(14),
        lineHeight: scale(18)
    }
};
